@@ -1,9 +1,10 @@
-import Test.Framework (defaultMain)
+import Test.Framework (Test, defaultMain, testGroup)
 import Test.Framework.Providers.QuickCheck2 (testProperty)
 import qualified Data.ByteString.Char8 as B
 import qualified Data.Double.Conversion.ByteString as B
 import qualified Data.Double.Conversion.Text as T
 import qualified Data.Text as T
+import qualified Regressions
 
 shortest :: (Double -> String) -> Double -> Double -> Bool
 shortest f a b = case read (f ab) of
@@ -12,8 +13,11 @@ shortest f a b = case read (f ab) of
                       | otherwise     -> ba == ab
   where ab = a / b
 
+tests :: Test
+tests = testGroup "Properties" [
+    testProperty "b_shortest" $ shortest (B.unpack . B.toShortest)
+  , testProperty "t_shortest" $ shortest (T.unpack . T.toShortest)
+  ]
+
 main :: IO ()
-main = defaultMain [
-         testProperty "b_shortest" $ shortest (B.unpack . B.toShortest)
-       , testProperty "t_shortest" $ shortest (T.unpack . T.toShortest)
-       ]
+main = defaultMain [tests, Regressions.tests]
